@@ -2,6 +2,14 @@
 #'
 #' Perform a spell check on document files or plain text.
 #'
+#' This function parses a file based on the file extension, and checks only
+#' text fields while ignoring code chunks and meta data. It works particularly
+#' well for markdown, but also latex, html, xml, pdf, and plain text are
+#' supported.
+#'
+#' For more information about the underlying spelling engine, see the
+#' [hunspell package](https://bit.ly/2EquLKy).
+#'
 #' @rdname spell_check_files
 #' @family spelling
 #' @inheritParams spell_check_package
@@ -67,11 +75,15 @@ spell_check_file_text <- function(file, dict){
 
 spell_check_file_rd <- function(rdfile, dict){
   text <- tools::RdTextFilter(rdfile)
+  Encoding(text) <- "UTF-8"
   spell_check_plain(text, dict = dict)
 }
 
 spell_check_file_md <- function(path, dict){
   words <- parse_text_md(path)
+
+  # Filter out citation keys, see https://github.com/ropensci/spelling/issues/9
+  words$text <- gsub("\\S*@\\S+", "", words$text, perl = TRUE)
   words$startline <- vapply(strsplit(words$position, ":", fixed = TRUE), `[[`, character(1), 1)
   bad_words <- hunspell::hunspell(words$text, dict = dict)
   vapply(sort(unique(unlist(bad_words))), function(word) {
